.. hide-toc: true

跨平台、多模态、高度自定义的骰系开发框架
===========================================================

.. include:: ../../README.rst
    :start-after: start-index
    :end-before: end-index


.. toctree::
    :hidden:

    about/index


.. toctree::
    :hidden:

    getting_started/index


.. toctree::
    :hidden:

    tutorials/index
    

.. toctree::
    :hidden:

    contributing/index


.. toctree::
    :hidden:

    community/index


.. toctree::
    :hidden:
    :caption: 开放 API 手册

    参考 <api/index.rst>
